@@ -40,20 +40,43 @@ class PipeCode(StrEnum):
     EXTRACT_ENVIRONMENT_BUILD = "extract_environment_build"
     EXTRACT_CODING_STANDARDS = "extract_coding_standards"
     EXTRACT_TEST_STRATEGY = "extract_test_strategy"
+    EXTRACT_CONTEXTUAL_GUIDELINES = "extract_contextual_guidelines"
     EXTRACT_COLLABORATION = "extract_collaboration"
+    EXTRACT_FEATURES_RECAP = "extract_features_recap"
 
     DOC_PROOFREAD = "doc_proofread"
     DOC_UPDATE = "doc_update"
     AI_INSTRUCTION_UPDATE = "ai_instruction_update"
 
+    # SWE diff analysis
+    WRITE_CHANGELOG = "write_changelog"
+    WRITE_CHANGELOG_ENHANCED = "write_changelog_enhanced"
+
+    # Text utilities
+    GENERATE_SPLIT_IDENTIFIERS = "generate_split_identifiers"
+
+    # SWE docs consistency check
+    CHECK_DOCS_INCONSISTENCIES = "check_doc_inconsistencies"
+
 
 def _get_pipe_descriptions() -> str:
     """Generate help text with pipe descriptions from TOML."""
     descriptions = {
         "extract_onboarding_documentation": "Extract comprehensive onboarding documentation from software project docs",
+        "extract_fundamentals": "Extract fundamental project information from documentation",
+        "extract_environment_build": "Extract environment setup and build information from documentation",
+        "extract_coding_standards": "Extract code quality and style information from documentation",
+        "extract_test_strategy": "Extract testing strategy and procedures from documentation",
+        "extract_contextual_guidelines": "Extract contextual development guidelines from documentation",
+        "extract_collaboration": "Extract collaboration and workflow information from documentation",
+        "extract_features_recap": "Extract and analyze software features from documentation",
         "doc_proofread": "Systematically proofread documentation against actual codebase to find inconsistencies",
         "doc_update": "Generate documentation update suggestions for docs/ directory",
         "ai_instruction_update": "Generate AI instruction update suggestions for AGENTS.md, CLAUDE.md, cursor rules",
+        "write_changelog": "Write a comprehensive changelog for a software project from git diff",
+        "write_changelog_enhanced": "Write a comprehensive changelog with draft and polish steps from git diff",
+        "generate_split_identifiers": "Analyze large text and generate optimal split identifiers",
+        "check_doc_inconsistencies": "Identify inconsistencies in a set of software engineering documents",
     }
 
     help_text = "\n\n"
@@ -256,8 +279,8 @@ def swe_from_repo_cmd(
 @app.command("swe-from-file")
 def swe_from_file_cmd(
     pipe_code: Annotated[
-        str,
-        typer.Argument(help="Pipeline code to execute for SWE analysis"),
+        PipeCode,
+        typer.Argument(help=f"Pipeline code to execute for SWE analysis.\n\n{_get_pipe_descriptions()}"),
     ],
     input_file_path: Annotated[
         str,
